package com.fjhx.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.config.TaskPoolConfig;
import com.fjhx.config.exception.ServiceException;
import com.fjhx.entity.EmailMessageAttachment;
import com.fjhx.mapper.EmailMessageAttachmentMapper;
import com.fjhx.service.IEmailMessageAttachmentService;
import com.fjhx.utils.EmailEngineUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import java.io.FileNotFoundException;
import java.util.List;
import java.util.concurrent.Executor;

/**
 * <p>
 * 文件附件 服务实现类
 * </p>
 *
 * @author zlj
 * @since 2022-12-21
 */
@Service
public class EmailMessageAttachmentServiceImpl extends ServiceImpl<EmailMessageAttachmentMapper, EmailMessageAttachment> implements IEmailMessageAttachmentService {

    @Qualifier(TaskPoolConfig.EXECUTOR)
    @Autowired
    private Executor syncExecutor;

    @Override
    public List<EmailMessageAttachment> getAttachmentList(String messageId) {
        return list(q -> q.eq(EmailMessageAttachment::getMessageId, messageId));
    }

    @Override
    public void downloadAttachment(String email, String attachmentId, String path) {
        try {
            EmailEngineUtil.downloadAttachment(email, attachmentId, path);
        } catch (FileNotFoundException e) {
            throw new ServiceException("下载附件失败");
        }
        syncExecutor.execute(() -> {
            EmailMessageAttachment attachment = new EmailMessageAttachment();
            attachment.setAttachmentId(attachmentId);
            attachment.setIsDownload(true);
            updateById(attachment);
        });
    }

}
