package com.fjhx.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.entity.EmailMessage;
import com.fjhx.mapper.EmailMessageMapper;
import com.fjhx.service.IEmailMessageService;
import com.fjhx.vo.GetEmailMessagePageVo;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zlj
 * @since 2022-12-21
 */
@Service
public class EmailMessageServiceImpl extends ServiceImpl<EmailMessageMapper, EmailMessage> implements IEmailMessageService {

    @Override
    public Page<EmailMessage> getPage(GetEmailMessagePageVo vo) {

        String email = vo.getEmail();
        Assert.notEmpty(email, "邮箱地址不能为空");

        Date beginTime = vo.getBeginTime();
        Date endTime = vo.getEndTime();
        String subject = vo.getSubject();
        String fromName = vo.getFromName();
        String fromAddress = vo.getFromAddress();

        return page(vo, q -> q
                .eq(EmailMessage::getEmail, email)
                .eq(EmailMessage::getIsShow, true)
                .eq(ObjectUtil.isNotEmpty(vo.getUnseen()), EmailMessage::getUnseen, vo.getUnseen())
                .between(ObjectUtil.isAllNotEmpty(beginTime, endTime), EmailMessage::getFromDate, beginTime, endTime)
                .like(ObjectUtil.isNotEmpty(subject), EmailMessage::getSubject, subject)
                .like(ObjectUtil.isNotEmpty(fromName), EmailMessage::getFromName, fromName)
                .like(ObjectUtil.isNotEmpty(fromAddress), EmailMessage::getFromAddress, fromAddress)
                .orderByDesc(EmailMessage::getFromDate)
        );

    }

    @Override
    public void delete(String messageId) {
        update(q -> q.eq(EmailMessage::getMessageId, messageId).set(EmailMessage::getIsShow, false));
    }

}
